Package: pogos
Title: PharmacOGenomics Ontology Support
Description: Provide simple utilities for querying bhklab PharmacoDB, modeling 
	API outputs, and integrating to cell and compound ontologies.
Version: 1.33.0
Author: Vince Carey <stvjc@channing.harvard.edu>
Suggests: knitr, DT, ontologyPlot, testthat, rmarkdown, BiocStyle
Imports: methods, S4Vectors, utils, shiny, ontoProc, ggplot2, graphics
Depends: R (>= 3.5.0), rjson (>= 0.2.15), httr (>= 1.3.1)
Maintainer: VJ Carey <stvjc@channing.harvard.edu>
License: Artistic-2.0
LazyLoad: yes
LazyData: yes
biocViews: Pharmacogenomics, PooledScreens, ImmunoOncology
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/pogos
git_branch: devel
git_last_commit: b30e578
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-30
NeedsCompilation: no
Packaged: 2026-04-30 23:36:46 UTC; biocbuild

# Generated by roxygen2: do not edit by hand

export(DRProfSet)
export(DRTraceSet)
export(basicDecoder)
export(compoundsByCell)
export(getDrugs)
export(iriCCLE)
export(rxdbQuery_v1)
export(topEndpoints_v1)
export(traces)
exportClasses(DRProfile)
exportClasses(DRTraceSet)
exportMethods("[")
exportMethods(plot)
import(ggplot2)
import(httr)
import(methods)
import(ontoProc)
import(rjson)
import(shiny)
importFrom(S4Vectors,DataFrame)
importFrom(graphics,lines)
importFrom(methods,is)
importFrom(utils,data)

---
title: "pogos -- PharmacOGenomics Ontology Support"
author: "Vincent J. Carey, stvjc at channing.harvard.edu"
date: "`r format(Sys.time(), '%B %d, %Y')`"
vignette: >
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteIndexEntry{pogos -- simple interface to bhklab PharmacoDB with emphasis on ontology}
  %\VignetteEncoding{UTF-8}
output:
  BiocStyle::html_document:
    highlight: pygments
    number_sections: yes
    theme: united
    toc_float: yes
---

# Introduction

bhklab's PharmacoDB unites multiple drug sensitivity databases.
A REST API is available and interfaces to some basic endpoints are
provided in this package.  We also provide some basic
support for working with the Cell Line Ontology and ChEBI.

A basic purpose of this package is to support exploration of
the completeness and utility 
of available ontologies for cell lines and drugs.
A relevant study of the possibility of "drug set
enrichment analysis" has been published
by [Napolitano and colleagues](https://www.ncbi.nlm.nih.gov/pubmed/26415724).

We note that detailed RESTful interrogation of many ontologies
is supported by the `r Biocpkg("rols")` package.  In the long
run we would like to make use of the EBI Ontology Lookup System
as a central resource of this package, but to develop concepts
at these early stages, static images of ontologies are employed.

```{r setup,echo=FALSE}
suppressMessages({
suppressPackageStartupMessages({
library(pogos)
library(S4Vectors)
library(DT)
library(ggplot2)
})
})
```

# Basic software design for pogos

This package attacks two problems: organization of data on
cell-line response to treatments by diverse compounds, and
communication with PharmacoDb.

## Data structures for pharmacogenomics

This package provides two key data structures for managing pharmacogenomic
experimental results

- `DRTraceSet`: for a given dosage schedule for a given compound, manage the
dose-response profiles for a number of cell lines. 
An example is
```{r lkcc}
iric = iriCCLE()
iric 
```
- `DRProfSet`: for a given cell line, provide the dose-response profiles for
a number of compounds.  Example:
```{r lkdrp}
drp = try(DRProfSet())
if (!inherits(drp, "try-error"))
 drp
```
This may fail if pharmacdb.pmgenomics.ca is down.

The `plot` method reveals a basic motivation for `DRTraceSet`.
```{r lkpl090, fig.height=2.5}
plot(iric)
```

The plot method for DRProfSet has a complementary purpose.
```{r lklll,fig.height=3.5}
if (!inherits(drp, "try-error"))
  plot(drp)
```

## Interrogating PharmacoDb

The communications part of the package is somewhat
fragile, as changes to the upstream service at
Princess Margaret can lead to failures here.

The heart of the query facility is shown here,
unevaluated.  The `datasetCodes` and `cellLineCodes`
are extracted from reference data that may itself
go out of date.
```
    xx = GET(sprintf("https://pharmacodb.pmgenomics.ca/api/v1/intersections/2/%d/%d?indent=true", 
        cellLineCodes[cell_line], datasetCodes[dataset]))
    ans = fromJSON(readBin(xx$content, what = "character"))
    ans = lapply(ans, function(comb) {
        new("DRProfile", cell_line = cell_line, dataset = dataset, 
            drug = comb$compound$name, drug_code = comb$compound$id, 
            cell_line_code = comb$cell_line$id, doses = vapply(comb$dose_responses, 
                function(x) x$dose, numeric(1)), responses = vapply(comb$dose_responses, 
                function(x) x$response, numeric(1)))
    })
```


# Some stored reference data

We precomputed tables for cell lines, compounds, and tissues.
These are available as DataFrame instances as
`cell_lines_v1`, `compounds_v1`, `datasets_v1`, and `tissues_v1`, in
the data element of the package.

Numerical ids are defined by the PharmacoDB.

## Cell lines
```{r lkk, echo=FALSE}
data(cell_lines_v1)
datatable(as.data.frame(cell_lines_v1), options=list(lengthMenu=c(3,5,10,50,100)))
```

## Compounds
```{r lkccc, echo=FALSE}
data(compounds_v1)
datatable(as.data.frame(compounds_v1), 
   options=list(lengthMenu=c(3,5,10,50,100)))
```

## Datasets
```{r lkccc2, echo=FALSE}
data(datasets_v1)
datatable(as.data.frame(datasets_v1))
```

## Coverage of pharmacogenomic compound names by ChEBI

As an illustration of long-term intention of this package, consider
the following snapshot of a slice of ChEBI.

```{r doch,fig=TRUE}
library(ontoProc)
cc = getOnto("chebi_full")
library(ontologyPlot)
onto_plot(cc, 
  c("CHEBI:134109", "CHEBI:61115", "CHEBI:75603", "CHEBI:37699", 
       "CHEBI:68481", "CHEBI:71178"), fontsize=24, shape="rect")
```
It is natural to map the compounds studied in pharmacogenomics to these
compound classes as a step towards understanding common and distinct
mechanisms of action.  But in the following display, we see
that some common chemotherapeutic agents are characterized in very
generic terms:

```{r lkmo, fig=TRUE}
onto_plot(cc, c("CHEBI:134109", "CHEBI:61115", "CHEBI:75603", "CHEBI:37699", 
   "CHEBI:68481", "CHEBI:71178", "CHEBI:52172", "CHEBI:64310", 
   "CHEBI:63632", "CHEBI:45863"), fontsize=28, shape="rect")
```

Should paclitaxel be identified as an "organic molecular entity"
with no additional detail?  Is there additional information in
ChEBI or related ontologies to help organize information on
related compounds?

## Relationships among cell lines

Cell line nomenclature is often unnatural.  The Cell Line
Ontology should be helpful in systematizing cell lines
used in pharmacogenomics.  Nevertheless there is
some apparent lack of consistency.

```{r ana,fig=TRUE}
clo = getOnto("cellLineOnto", year_added="2022")
smoc = c("CLO:0000517", "CLO:0000560", "CLO:0000563", "CLO:0001072", 
"CLO:0001088", "CLO:0001138", "CLO:0007606")
onto_plot(clo, smoc)
```

The MCF7 line should probably be annotated as related to human
mammary tissue.


# Working with specific elements

We want to maximize utility of institutionally curated
terminology for components of pharmacodb.

## Cell line identifiers

### Bridging to Cell Line Ontology

The following identifiers are available in the PharmacoDB cell lines:
```
c("143B", "1321N1", "184B5")
```
What are they?  What organs do they represent?  One way
to proceed is through parent terms in Cell Line Ontology.
```{r lkoo}
library(ontoProc)
clo = getOnto("cellLineOnto", year_added="2022")
minds = which(clo$name %in% c("143B cell", "1321N1 cell", "184B5 cell"))
tags = clo$id[minds]
clo$name[ unlist(clo$parent[tags]) ]
```
TODO: how can we connect the anatomic vocabulary in these terms
to formal anatomical terms in UBERON or CARO?

### Vocabularies of anatomy

The Experimental Factor Ontology unifies various ontologies and
includes terms related to anatomic systems.  At least with the
infrastructure available in `r CRANpkg("ontologyIndex")` and
`r CRANpkg("ontologyPlot")`, it seems there are opportunities to
add meaningful connections.

```{r lkefo, fig=TRUE}
ee = getOnto("efoOnto")
onto_plot(ee, c("UBERON:0000474", "UBERON:0000079", 
  "UBERON:0000990", "UBERON:0000995", "UBERON:0003982", 
  "UBERON:0000310", "UBERON:0002107", "UBERON:0001264", 
  "UBERON:0002113", "UBERON:0001007", "UBERON:0002530", 
  "UBERON:6007435", "UBERON:0004122", "UBERON:0001008"))
```

It is likely important to remember the distinction between an
ontology, a structured collection of concept terms, and a
curated vocabulary or ontology annotation, which covers
concept "instances".

## Compounds

### Bridging to ChEBI

This will involve more work.  We have the compounds in PharmacoDB.
How many match the compound names in Chebi? 
```{r lkcom}
chl = getOnto("chebi_full")
allch = chl$name
mm = allch[match(tolower(compounds_v1[,2]), tolower(allch), nomatch=0)]
round(length(mm)/nrow(compounds_v1),2) # not high
datatable(data.frame(id=names(mm), comp=as.character(mm)))
```

Direct matches are relatively rare.  Attempts to use approximate
matching with agrep have so far been unproductive.  As an
example, which we do not run:

```{r srchsym, eval=FALSE}
notin = setdiff(compounds_v1$name, mm)
library(parallel)
options(mc.cores=2)
allch = tolower(allch)
notin = tolower(notin)
lk50 = mclapply(notin[1:50], function(x) { cat(x);
       order(adist(x, allch))[1:5]})
names(lk50) = notin[1:50]
aa = do.call(cbind, lk50[1:50])
ttt = t(apply(aa,2,function(x) allch[x])[1:3,])
```

# Retrieving dose-response data for cell-line/compound intersections

Given a cell-line code and a database, we can retrieve all the experiments
associated with it in that database.

CCLE for MCF-7:
```{r lkcomb,cache=TRUE}
library(rjson)
library(httr)
xx = GET("https://pharmacodb.pmgenomics.ca/api/v1/intersections/2/895/1?indent=true")
if (as.numeric(xx$status_code) == 200) {
 ans = fromJSON(readBin(xx$content, what="character"))
 doses1 = sapply(ans[[1]]$dose_responses, function(x) x[[1]])
 resp1 =  sapply(ans[[1]]$dose_responses, function(x) x[[2]])
 }
```
This code only runs if pharmacodb.pmgenomics.ca is responsive.

The `compoundsByCell` function employs this pattern to establish
lists of experiments per cell type.

We can recreate (approximately: the dose and response units
need to be clarified) Figure 4b from Barretina et al. 2012
as follows (defaults to DRTraceSet are specifically chosen
to compute this figure):

```{r lkbar, fig=TRUE}
library(ggplot2)
drt = try(DRTraceSet(dataset="CCLE"))
if (!inherits(drt, "try-error")) plot(drt)
```
This code only runs if pharmacodb.pmgenomics.ca is responsive.

#' trace extractor
#' @param x instance of DRTraceSet
#' @importFrom methods is
#' @return a list of DRProfile instances
#' @examples
#' iri = iriCCLE()
#' str(traces(iri)[[1]])
#' @export
traces = function(x) {
 stopifnot(is(x, "DRTraceSet"))
 slot(x, "traces")
}

#' DRProfSet is a class for managing dose-response information about 
#' cell lines from a pharmacogenomics dataset
#' @import methods
#' @importFrom graphics lines
#' @rdname DRProfSet
#' @aliases DRProfSet-class DRProfSet
#' @examples
#' if (interactive()) trs = DRTraceSet() else trs = iriCCLE()
#' ps = traces(trs)[[1]]
#' ps
#' getDrugs(ps)
#' @export
setClass("DRProfile", representation(cell_line = "character", 
    drug = "character", drug_code = "numeric", cell_line_code = "numeric", 
    dataset = "character", doses = "numeric", 
    responses = "numeric"))
setClass("DRProfSet", representation(cell_line = "character", 
    dataset = "character", DRProfiles = "list"))
setMethod("show", "DRProfSet", function(object) {
    cat(sprintf("DRProfSet with %d dose-response profiles for cell line %s\n dataset: %s\n", 
        length(object@DRProfiles), object@cell_line, object@dataset))
})

#' getDrugs extracts drug list
#' @rdname DRProfSet
#' @param x instance of DRProfSet
#' @return getDrugs: character vector
#' @aliases getDrugs,DRProfSet-method
#' @export
setGeneric("getDrugs", function(x) standardGeneric("getDrugs"))
setMethod("getDrugs", "DRProfSet", 
    function(x) vapply(x@DRProfiles, function(x) x@drug, character(1)))

#' subscripting on DRProfSet extracts a profile for a single drug 
#' whose name constitutes the index
#' @param x instance of DRProfSet
#' @param i character(1) drug name
#' @param j not used
#' @param \dots not used
#' @param drop logical(1) not used
#' @return a DRProfSet instance restricted to experiments involving the selected drug
#' @export
setMethod("[", c("DRProfSet", "character", "ANY"), 
    function(x, i, j, ..., drop = TRUE) {
      ind = match(i, getDrugs(x))
      if (length(ind) == 0) 
          stop(sprintf("index drug (%s) not found\n", i))
      if (length(ind) > 1) {
        message("multiple matches found, using first")  # FIXME
        ind = ind[1]
      }
      x@DRProfiles = x@DRProfiles[ind]
      x
    })


DRtraces = function(drp, ylab = "response", ...) {
    doses = lapply(drp@DRProfiles, function(x) x@doses)
    resps = lapply(drp@DRProfiles, function(x) x@responses)
    xlim = range(unlist(doses))
    ylim = range(unlist(resps))
    plot(doses[[1]], resps[[1]], xlim = c(0.95, 1.05) * xlim, ylim = c(0.95, 1.05) * 
        ylim, ylab = ylab,  
        main = paste(drp@dataset, drp@cell_line, sep = " "), xlab = "dose", 
        type = "l", ...)
    if (length(doses) > 1) 
        uu = lapply(2:length(doses), function(x) lines(doses[[x]], resps[[x]], col = x, 
            lty = x))
    invisible(NULL)
}

lkc = function(cell_line = "MCF7", dataset = "CCLE") {
    data(cell_lines_v1)
    data(datasets_v1)
    data(compounds_v1)
    cellLineVec = cell_lines_v1[, "name"]
    cellLineCodes = cell_lines_v1[, "id"]
    compoundVec = compounds_v1[, "name"]
    compoundCodes = compounds_v1[, "id"]
    datasetVec = datasets_v1[, "name"]
    datasetCodes = datasets_v1[, "id"]
    names(datasetCodes) = datasetVec
    names(cellLineCodes) = cellLineVec
    names(compoundCodes) = compoundVec
    xx = GET(sprintf("https://pharmacodb.pmgenomics.ca/api/v1/intersections/2/%d/%d?indent=true", 
        cellLineCodes[cell_line], datasetCodes[dataset]))
    ans = fromJSON(readBin(xx$content, what = "character"))
    ans = lapply(ans, function(comb) {
        new("DRProfile", cell_line = cell_line, dataset = dataset, 
            drug = comb$compound$name, 
            drug_code = comb$compound$id, 
            cell_line_code = comb$cell_line$id, 
            doses = vapply(comb$dose_responses, 
                function(x) x$dose, numeric(1)), 
            responses = vapply(comb$dose_responses, 
                function(x) x$response, numeric(1)))
    })
    new("DRProfSet", cell_line = cell_line, dataset = dataset, DRProfiles = ans)
}

#' DRTraceSet class manages dose-response information for a single cell line, multiple drugs
#' @rdname DRTraceSet
#' @export
setClass("DRTraceSet", representation(cell_lines = "character", drug = "character", 
    dataset = "character", traces = "list"))
setMethod("show", "DRTraceSet", function(object) {
    cat(sprintf("DRTraceSet for %d cell lines, drug %s, dataset %s\n", 
        length(object@cell_lines), object@drug, object@dataset))
})
.traceDF = function(drts) {
    ds = lapply(drts@traces, function(x) x@DRProfiles[[1]]@doses)
    rs = lapply(drts@traces, function(x) x@DRProfiles[[1]]@responses)
    cls = vapply(drts@traces, function(x) x@cell_line, character(1))
    ns = vapply(ds, length, numeric(1))
    cls = rep(cls, ns)
    data.frame(dose = unlist(ds), response = unlist(rs), 
               cell_line = cls, dataset = drts@dataset, 
               drug = drts@drug)
}

#' @rdname DRTraceSet
#' @import ggplot2
#' @param x for plot: instance of DRTraceSet
#' @param y for plot: not used
#' @param \dots not used
#' @export
setMethod("plot", c("DRTraceSet", "missing"), function(x, y, ...) {
    df = .traceDF(x)  # defines cell_line, dose, response
    ggplot(df, aes(x = log(dose), y = response, colour = cell_line)) + geom_line() + ggtitle(paste(x@drug, x@dataset))
})

#' DRTraceSet constructor for multiple cell lines, single drug, single dataset
#' @param cell_lines character vector of cell line names, must be found 
#' in `cell_lines_v1` data of pogos package
#' @param drug character(1) drug name in `compounds_v1`
#' @param dataset character(1) dataset known to pharmacodb.pmgenomics.ca
#' @note Will query pharmacodb for relevant dose-response information
#' @return instance of DRTraceSet
#' @examples
#' val = try(DRTraceSet())
#' if (!inherits(val, "try-error")) val
#' # otherwise pharmacodb.pmgenomics.ca is down
#' @export
DRTraceSet = function(cell_lines = c("SK-ES-1", "TC-71", "MHH-ES-1", "HCC-56", "SK-HEP-1"), 
    drug = "Irinotecan", dataset = "CCLE") {
    if (length(drug) != 1) 
        stop("currently handles only one drug at a time")
    st1 = lapply(cell_lines, function(x) try(lkc(x, dataset), silent = TRUE))
    errs = vapply(st1, function(x) inherits(x, "try-error") || length(x@DRProfiles) == 
        0, logical(1))
    if (any(errs)) {
        if (all(errs)) 
            stop("no data for requested cell lines")
        message("no data for some requested cell lines:")
        message(paste(" ", cell_lines[which(errs)], sep = " "))
        st1 = st1[-which(errs)]
    }
    kp = seq_len(length(cell_lines))
    if (any(errs)) 
        kp = kp[-which(errs)]
    new("DRTraceSet", cell_lines = cell_lines[kp], drug = drug, dataset = dataset, 
        traces = lapply(st1, function(x) x[drug]))
}


#' DRProfSet manages all data from a given cell line from
#' a pharmacogenomics source
#' @param cell_line character(1) cell line name, entries in cell_lines_v1
#' @param dataset character(1) resource name, entries in datasets_v1
#' @return instance of DRProfSet
#' @examples
#' if (interactive()) DRProfSet()
#' @export
DRProfSet = function(cell_line = "MCF7", dataset = "CCLE") {
  try(lkc(cell_line=cell_line, dataset=dataset))
}


.profDF = function (drp) 
{
    ds = lapply(drp@DRProfiles, function(x) x@doses)
    rs = lapply(drp@DRProfiles, function(x) x@responses)
    cls = vapply(drp@DRProfiles, function(x) x@cell_line, character(1))
    drgs = lapply(drp@DRProfiles, function(x) x@drug)
    ns = vapply(ds, length, numeric(1))
    cls = rep(cls, ns)
    data.frame(dose = unlist(ds), response = unlist(rs), cell_line = cls, 
        dataset = drp@dataset, drug = rep(unlist(drgs),ns))
}

#' @rdname DRProfSet
#' @import ggplot2
#' @param y for plot: not used
#' @param \dots not used
#' @export
setMethod("plot", c("DRProfSet", "missing"), function(x,y, ...) {
 .df = .profDF(x)
 ggplot(.df, aes(x=log(dose), y=response, colour=drug)) + 
   geom_line() + ggtitle(paste(x@cell_line, x@dataset))
})

library(pogos)

context("testTargets")
test_that("test suite knows how many functions are exported", {
    exported = ls("package:pogos")
    expect_true(length(exported) >= 7)
})

context("testInterface")
test_that("query resolves", {
    qout = try(rxdbQuery_v1("cell_lines"))  # yields 30; append '?all=true' to retrieve all
    if (!inherits(qout, "try-error")) {
     expect_true(all(names(qout[[1]]) == c("id", "name")))
     expect_true(length(sapply(qout, function(x) x[[2]])) == 30)
     expect_error(DRTraceSet("SNU-719"))
     expect_true(is(DRTraceSet(c("MCF7", "SNU-719")), "DRTraceSet"))
    }
})

#' enumerate top level endpoint terms for bhklab PharmacoDB API
#' @return a character vector of available endpoints
#' @examples 
#' topEndpoints_v1()
#' @export
topEndpoints_v1 = function() {
    c("cell_lines", "tissues", "compounds", "datasets", "experiments", "intersections", 
        "stats")
}

#' convert binary output of GET()$content to list 
#' @import httr
#' @import rjson
#' @param x string suitable for input to GET as GET(x)
#' @return output of fromJSON, typically a list
#' @examples
#' cl = try(basicDecoder('https://pharmacodb.pmgenomics.ca/api/v1/cell_lines'))
#' if (!inherits(cl, "try-error")) unlist(cl) # or pmgenomics is down
#' @export
basicDecoder = function(x) fromJSON(readBin(GET(x)$content, what = "character"))

#' very simple query formulation, build queries using endpoints of bhklab PharmacoDB API
#' @importFrom S4Vectors DataFrame
#' @param url of a PharmacoDB server API target
#' @param \dots typically a string representing an API endpoint, will be processed by unlist() and then to paste0 preceded by \code{url}
#' @param decoder a function of one argument that will be applied to API response (typically JSON)
#' @return typically a list, dependent on decoder parameter
#' @examples
#' qout = try(rxdbQuery_v1('cell_lines')) # yields 30; append '?all=true' to retrieve all
#' if (!inherits(qout, "try-error")) unlist(lapply(qout, function(x) x[[2]]))
#' # or pmgenomics.ca is down
#' @export
rxdbQuery_v1 = function(..., url = "https://pharmacodb.pmgenomics.ca/api/v1/", decoder = basicDecoder) {
    parms = list(...)
    decoder(paste0(url, unlist(parms)))
}

compoundTable = function(postfix = "?all=true") {
    comps = rxdbQuery_v1(paste0("compounds", postfix))
    ids = vapply(comps, "[[", "id", character(1))
    nms = vapply(comps, "[[", "name", character(1))
    DataFrame(compound_id = ids, compound = nms)
}

buildMap = function(endpoint = "cell_lines", postfix = "?all=true") {
    recs = rxdbQuery_v1(paste0(endpoint, postfix))
    ids = vapply(recs, "[[", "id", character(1))
    nms = vapply(recs, "[[", "name", character(1))
    DataFrame(id = ids, name = nms)
}

#' compounds_v1: serialization of compounds info from PharmacoDb v1
#' @importFrom utils data
#' @docType data
#' @format S4Vectors DataFrame instance
#' @source PharmacoDb Sept 2017
#' @examples
#' data(compounds_v1)
#' head(compounds_v1)
"compounds_v1"
#' @rdname compounds_v1
#' @docType data
#' @format S4Vectors DataFrame instance
#' @source PharmacoDb Sept 2017
#' @examples
#' data(tissues_v1)
#' head(tissues_v1)
"tissues_v1"
#' @rdname compounds_v1
#' @docType data
#' @format S4Vectors DataFrame instance
#' @source PharmacoDb Sept 2017
#' @examples
#' data(cell_lines_v1)
#' head(cell_lines_v1)
"cell_lines_v1"
#' @rdname compounds_v1
#' @docType data
#' @format S4Vectors DataFrame instance
#' @source PharmacoDb Sept 2017
#' @examples
#' data(datasets_v1)
#' head(datasets_v1)
"datasets_v1"

#' @rdname compounds_v1
#' @docType data
#' @format DRTraceSet instance
#' @source PharmacoDb April 2018
#' @examples
#' data(CCLE_drts)
#' CCLE_drts
"CCLE_drts"

#' initial version of compound browser over pharmacoDb cells
#' @import shiny
#' @import ontoProc
#' @note Simple shiny app demonstrating coverage of PharmacoDb 
#' compounds by CHEBI.  If a cell line selected is not present 
#' in selected dataset, the app will wait for a 
#' compatible selection to be made.
#' @return only used for side effect of running shiny app
#' @examples
#' if (!requireNamespace("shiny")) stop("install shiny to use compoundsByCell")
#' if (interactive()) print(compoundsByCell())
#' @export
compoundsByCell = function() {
data(cell_lines_v1, package="pogos")
data(compounds_v1, package="pogos")
data(datasets_v1, package="pogos")
message("acquiring CHEBI")
if (!exists("cc")) cc = getChebiOnto()
message("done")
cellLineVec = cell_lines_v1[,"name"]
cellLineCodes = cell_lines_v1[,"id"]
compoundVec = compounds_v1[,"name"]
compoundCodes = compounds_v1[,"id"]
datasetVec = datasets_v1[,"name"]
datasetCodes = datasets_v1[,"id"]
names(datasetCodes) = datasetVec
names(cellLineCodes) = cellLineVec
names(compoundCodes) = compoundVec

ui = fluidPage(
 sidebarLayout(
  sidebarPanel(
   helpText("This app enumerates compounds that have been tested against selected cell lines in selected experiments."),
   selectInput("cell", "cell line", choices=cellLineVec, selected="MCF7"),
   #selectInput("compound", "compound", choices=compoundVec, selected=compoundVec[1]),
   selectInput("dataset", "dataset", choices=datasetVec, selected="CCLE")
   ),
  mainPanel( 
      #textOutput("cell"), textOutput("dataset"),
      helpText("Table may be searched or sorted by fields \
for compound identifier or term parent in ChEBI\n"),
      dataTableOutput("nres")
   )
  )
 )

server = function(input, output) {
 output$cell = renderText( input$cell )
 output$compound = renderText( input$compound )
 output$dataset = renderText( input$dataset )
 output$nres = renderDataTable({
    xx = GET(
       sprintf("https://pharmacodb.pmgenomics.ca/api/v1/intersections/2/%d/%d?indent=true",
       cellLineCodes[input$cell], datasetCodes[input$dataset] ))
    ans = fromJSON(readBin(xx$content, what="character"))
    validate(need(length(ans)>0, "cell line not tested in selected experiment"))
    if (length(ans)>0) {
      alld = vapply(ans, function(x) x[["compound"]], vector("list", 2)) #"[[", "compound", vector("list", 2)) #, character(1))
      dn = as.character(alld[2,])
      chebn = tolower(cc$name)
      checo = names(cc$name)
      chepar = vapply(cc$parents[cc$id], function(x)x[1], character(1))
      cheparn = as.character(cc$name[chepar])
      lk = match(tolower(dn), chebn, nomatch=NA)
      chema = checo[lk]
      cheparn = cheparn[lk]
uwrap = function(id)
   sprintf("<A href='http://www.ebi.ac.uk/chebi/chebiOntology.do?chebiId=%s' target='_blank'>%s</A>", id, id)
      wrid = a(href=uwrap(chema), chema)
      nn = data.frame(drug=dn, chebi=uwrap(chema), parent=cheparn, stringsAsFactors=FALSE)
      } 
    else nn = data.frame(n=as.character(length(ans)), stringsAsFactors=FALSE)
    nn
    }, escape=FALSE)
}

print(shinyApp(ui, server))
}

#' obtain an example trace set stored locally, for irinotecan and selected cell lines
#' @return an instance of DRTraceSet
#' @examples
#' iri = iriCCLE()
#' iri
#' plot(iri)
#' @export
iriCCLE = function() .load_mock("iriCCLE")

.load_mock = function (stub) 
{
    get(load(system.file(sprintf("mocks/%s.rda", stub), package = "pogos")))
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lkcomb.R
\docType{class}
\name{DRTraceSet-class}
\alias{DRTraceSet-class}
\alias{plot,DRTraceSet,missing-method}
\alias{DRTraceSet}
\title{DRTraceSet class manages dose-response information for a single cell line, multiple drugs}
\usage{
\S4method{plot}{DRTraceSet,missing}(x, y, ...)

DRTraceSet(
  cell_lines = c("SK-ES-1", "TC-71", "MHH-ES-1", "HCC-56", "SK-HEP-1"),
  drug = "Irinotecan",
  dataset = "CCLE"
)
}
\arguments{
\item{x}{for plot: instance of DRTraceSet}

\item{y}{for plot: not used}

\item{\dots}{not used}

\item{cell_lines}{character vector of cell line names, must be found 
in `cell_lines_v1` data of pogos package}

\item{drug}{character(1) drug name in `compounds_v1`}

\item{dataset}{character(1) dataset known to pharmacodb.pmgenomics.ca}
}
\value{
instance of DRTraceSet
}
\description{
DRTraceSet class manages dose-response information for a single cell line, multiple drugs

DRTraceSet constructor for multiple cell lines, single drug, single dataset
}
\note{
Will query pharmacodb for relevant dose-response information
}
\examples{
val = try(DRTraceSet())
if (!inherits(val, "try-error")) val
# otherwise pharmacodb.pmgenomics.ca is down
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rxdbHandling.R
\name{topEndpoints_v1}
\alias{topEndpoints_v1}
\title{enumerate top level endpoint terms for bhklab PharmacoDB API}
\usage{
topEndpoints_v1()
}
\value{
a character vector of available endpoints
}
\description{
enumerate top level endpoint terms for bhklab PharmacoDB API
}
\examples{
topEndpoints_v1()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shin.R
\name{compoundsByCell}
\alias{compoundsByCell}
\title{initial version of compound browser over pharmacoDb cells}
\usage{
compoundsByCell()
}
\value{
only used for side effect of running shiny app
}
\description{
initial version of compound browser over pharmacoDb cells
}
\note{
Simple shiny app demonstrating coverage of PharmacoDb 
compounds by CHEBI.  If a cell line selected is not present 
in selected dataset, the app will wait for a 
compatible selection to be made.
}
\examples{
if (!requireNamespace("shiny")) stop("install shiny to use compoundsByCell")
if (interactive()) print(compoundsByCell())
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{compounds_v1}
\alias{compounds_v1}
\alias{tissues_v1}
\alias{cell_lines_v1}
\alias{datasets_v1}
\alias{CCLE_drts}
\title{compounds_v1: serialization of compounds info from PharmacoDb v1}
\format{
S4Vectors DataFrame instance

S4Vectors DataFrame instance

S4Vectors DataFrame instance

S4Vectors DataFrame instance

DRTraceSet instance
}
\source{
PharmacoDb Sept 2017

PharmacoDb Sept 2017

PharmacoDb Sept 2017

PharmacoDb Sept 2017

PharmacoDb April 2018
}
\usage{
compounds_v1

tissues_v1

cell_lines_v1

datasets_v1

CCLE_drts
}
\description{
compounds_v1: serialization of compounds info from PharmacoDb v1
}
\examples{
data(compounds_v1)
head(compounds_v1)
data(tissues_v1)
head(tissues_v1)
data(cell_lines_v1)
head(cell_lines_v1)
data(datasets_v1)
head(datasets_v1)
data(CCLE_drts)
CCLE_drts
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rxdbHandling.R
\name{rxdbQuery_v1}
\alias{rxdbQuery_v1}
\title{very simple query formulation, build queries using endpoints of bhklab PharmacoDB API}
\usage{
rxdbQuery_v1(
  ...,
  url = "https://pharmacodb.pmgenomics.ca/api/v1/",
  decoder = basicDecoder
)
}
\arguments{
\item{\dots}{typically a string representing an API endpoint, will be processed by unlist() and then to paste0 preceded by \code{url}}

\item{url}{of a PharmacoDB server API target}

\item{decoder}{a function of one argument that will be applied to API response (typically JSON)}
}
\value{
typically a list, dependent on decoder parameter
}
\description{
very simple query formulation, build queries using endpoints of bhklab PharmacoDB API
}
\examples{
qout = try(rxdbQuery_v1('cell_lines')) # yields 30; append '?all=true' to retrieve all
if (!inherits(qout, "try-error")) unlist(lapply(qout, function(x) x[[2]]))
# or pmgenomics.ca is down
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rxdbHandling.R
\name{basicDecoder}
\alias{basicDecoder}
\title{convert binary output of GET()$content to list}
\usage{
basicDecoder(x)
}
\arguments{
\item{x}{string suitable for input to GET as GET(x)}
}
\value{
output of fromJSON, typically a list
}
\description{
convert binary output of GET()$content to list
}
\examples{
cl = try(basicDecoder('https://pharmacodb.pmgenomics.ca/api/v1/cell_lines'))
if (!inherits(cl, "try-error")) unlist(cl) # or pmgenomics is down
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lkcomb.R
\name{[,DRProfSet,character,ANY,ANY-method}
\alias{[,DRProfSet,character,ANY,ANY-method}
\title{subscripting on DRProfSet extracts a profile for a single drug 
whose name constitutes the index}
\usage{
\S4method{[}{DRProfSet,character,ANY,ANY}(x, i, j, ..., drop = TRUE)
}
\arguments{
\item{x}{instance of DRProfSet}

\item{i}{character(1) drug name}

\item{j}{not used}

\item{\dots}{not used}

\item{drop}{logical(1) not used}
}
\value{
a DRProfSet instance restricted to experiments involving the selected drug
}
\description{
subscripting on DRProfSet extracts a profile for a single drug 
whose name constitutes the index
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mock.R
\name{iriCCLE}
\alias{iriCCLE}
\title{obtain an example trace set stored locally, for irinotecan and selected cell lines}
\usage{
iriCCLE()
}
\value{
an instance of DRTraceSet
}
\description{
obtain an example trace set stored locally, for irinotecan and selected cell lines
}
\examples{
iri = iriCCLE()
iri
plot(iri)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lkcomb.R
\name{traces}
\alias{traces}
\title{trace extractor}
\usage{
traces(x)
}
\arguments{
\item{x}{instance of DRTraceSet}
}
\value{
a list of DRProfile instances
}
\description{
trace extractor
}
\examples{
iri = iriCCLE()
str(traces(iri)[[1]])
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lkcomb.R
\docType{class}
\name{DRProfile-class}
\alias{DRProfile-class}
\alias{DRProfSet-class}
\alias{DRProfSet}
\alias{getDrugs}
\alias{getDrugs,DRProfSet-method}
\alias{plot,DRProfSet,missing-method}
\title{DRProfSet is a class for managing dose-response information about 
cell lines from a pharmacogenomics dataset}
\usage{
getDrugs(x)

DRProfSet(cell_line = "MCF7", dataset = "CCLE")

\S4method{plot}{DRProfSet,missing}(x, y, ...)
}
\arguments{
\item{x}{instance of DRProfSet}

\item{cell_line}{character(1) cell line name, entries in cell_lines_v1}

\item{dataset}{character(1) resource name, entries in datasets_v1}

\item{y}{for plot: not used}

\item{\dots}{not used}
}
\value{
getDrugs: character vector

instance of DRProfSet
}
\description{
DRProfSet is a class for managing dose-response information about 
cell lines from a pharmacogenomics dataset

getDrugs extracts drug list

DRProfSet manages all data from a given cell line from
a pharmacogenomics source
}
\examples{
if (interactive()) trs = DRTraceSet() else trs = iriCCLE()
ps = traces(trs)[[1]]
ps
getDrugs(ps)
if (interactive()) DRProfSet()
}
